==> provider_software_3.3.2.tar.gz: provider_software_3.3.2/lib/biocase/wrapper/protocol/inventory/inventory_response.py <==
# -*- coding: utf8 -*-
'''
**********************************************
*      P R O T O C O L - C L A S S
**********************************************
$RCSfile: biocase_response.py,v $
$Revision: 1236 $
$Author: j.holetschek $
$Date: 2012-11-26 10:34:53 +0100 (Mo, 26. Nov 2012) $
'''

from datetime import datetime
import xml.etree.ElementTree as ET
from biocase.tools.xmlutils import element, subelement, addOptionalAttributes
from biocase.wrapper.protocol.base_response import ResponseBaseClass
from biocase.archive.general import list_archives, filenamizeDatasetTitle

import biocase.configuration
cfg = biocase.configuration.Cfg()

import logging
log = logging.getLogger("pywrapper.protocol.inventory")


# ------------------------------------------------------------------------------------
class ResponseClass(ResponseBaseClass):
    __protocolURL__ = 'http://www.bgbm.org/biodivinf/schema/dsi_1_0.xsd'
    __protocolNS__  = 'http://www.biocase.org/schemas/dsi/1.0'

    # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    def __init__(self, dsaObj, diagnosticsHandler):
        ResponseBaseClass.__init__(self, dsaObj, diagnosticsHandler) 
        # root element
        ns=self.__class__.__protocolNS__
        xsi = 'http://www.w3.org/2001/XMLSchema-instance'
        self.doc = element(ns, "inventory")
        addOptionalAttributes(self.doc, xsi, schemaLocation=ns+' '+self.__class__.__protocolURL__)
        comment = ET.Comment("IMPORTANT NOTE: The ABCD2.06 and HISPID5 archives produced by this version of the BioCASe Provider Software are NOT dataset-aware yet. Each XML archive listed in this inventory stores all records published by the data source.")
        self.doc[0:0]=[comment]
        
        # Construct inventory
        self.status = subelement(self.doc, ns, "status", "Failed")
        subelement(self.doc, ns, "created", datetime.now().isoformat())
        subelement(self.doc, ns, "service_url", self.dsaObj.getBioCASeAccessPoint())
        self.datasets = subelement(self.doc, ns, "datasets")

        # Diagnostics 
        self._diagnostics = subelement(self.doc, ns, "diagnostics")

    # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    def setOKStatus(self):
        self.status.text = "OK"

    # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    def postprocessMessage(self, requestObj, dbmodVersion):
        ns = self.__class__.__protocolNS__
        if len(self.diagnosticsHandler.diagnostics) > 0:
            for d in self.diagnosticsHandler.diagnostics:
                # This check is done to skip info/debug messages that have been inserted before the DSA's debug level was loaded from config file
                if not (d.severity == 'DEBUG' and self.getPsfObj().getLogLevel() > 10) and not (d.severity == 'INFO' and self.getPsfObj().getLogLevel() > 20):
                    subelement(self._diagnostics, ns, "diagnostic", content=d.msg, severity=d.severity, code=d.code)

    # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    def setInventoryContent(self, datasetList):
        ns = self.__class__.__protocolNS__

        # Check datasetLIst
        if datasetList == [] or datasetList == [None]:
            log.info("No datasets published by this data source.")
            self.setOKStatus()
        else:
            log.info("Listing archives for datasets %s." % (str(datasetList)))
            try:
                # Get archive list and loop through dataset list
                l = list_archives(self.dsaObj.name)
                log.debug(l)
                for datasetTitle in datasetList:
                    ds = subelement(self.datasets, ns, "dataset")
                    subelement(ds, ns, "title", datasetTitle)
                    subelement(ds, ns, "id", datasetTitle)
                    archives = subelement(ds, ns, "archives")
                    title = filenamizeDatasetTitle(datasetTitle)
                    # Temorary implementation until ABCD2.06/HISPID5 archiving is dataset-aware
                    if l.has_key(title):
                        # DwC row type is always occurrence
                        (url, created) = l[title]
                        subelement(archives, ns, "archive", url, modified=created.isoformat(), rowType="http://rs.tdwg.org/dwc/terms/Occurrence")
                    if l.has_key('ABCD_2.06'):
                        (url, created) = l['ABCD_2.06']
                        subelement(archives, ns, "archive", url, modified=created.isoformat(), namespace="http://www.tdwg.org/schemas/abcd/2.06")
                    if l.has_key('ABCDEFG_2.06'):
                        (url, created) = l['ABCDEFG_2.06']
                        subelement(archives, ns, "archive", url, modified=created.isoformat(), namespace="http://www.tdwg.org/schemas/abcd/2.06")
                    if l.has_key('ABCDDNA_2.06'):
                        (url, created) = l['ABCDDNA_2.06']
                        subelement(archives, ns, "archive", url, modified=created.isoformat(), namespace="http://www.tdwg.org/schemas/abcd/2.06")
                    if l.has_key('HISPID_5'):
                        (url, created) = l['HISPID_5']
                        subelement(archives, ns, "archive", url, modified=created.isoformat(), namespace="http://www.chah.org.au/schemas/hispid/5")

                # Last, set status
                self.setOKStatus()

            except Exception, err:
                log.error(err)

==> provider_software_3.4.tar.gz: provider_software_3.4/lib/biocase/wrapper/protocol/inventory/inventory_response.py <==
# -*- coding: utf8 -*-
'''
**********************************************
*      P R O T O C O L - C L A S S
**********************************************
$RCSfile: biocase_response.py,v $
$Revision: 1275 $
$Author: j.holetschek $
$Date: 2013-02-18 18:39:16 +0100 (Mo, 18. Feb 2013) $
'''

from datetime import datetime
#import xml.etree.ElementTree as ET
from biocase.tools.xmlutils import element, subelement, addOptionalAttributes
from biocase.wrapper.protocol.base_response import ResponseBaseClass
from biocase.archive.general import inventory_by_dataset, ROWTYPE_DWCA

import biocase.configuration
cfg = biocase.configuration.Cfg()

import logging
log = logging.getLogger("pywrapper.protocol.inventory")


# ------------------------------------------------------------------------------------
class ResponseClass(ResponseBaseClass):
    __protocolURL__ = 'http://www.bgbm.org/biodivinf/schema/dsi_1_0.xsd'
    __protocolNS__ = 'http://www.biocase.org/schemas/dsi/1.0'

    # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    def __init__(self, dsaObj, diagnosticsHandler):
        ResponseBaseClass.__init__(self, dsaObj, diagnosticsHandler)
        # root element
        ns = self.__class__.__protocolNS__
        xsi = 'http://www.w3.org/2001/XMLSchema-instance'
        self.doc = element(ns, "inventory")
        addOptionalAttributes(self.doc, xsi, schemaLocation=ns + ' ' + self.__class__.__protocolURL__)
        #comment = ET.Comment("IMPORTANT NOTE: The ABCD2.06 and HISPID5 archives produced by this version of the BioCASe Provider Software are NOT dataset-aware yet. Each XML archive listed in this inventory stores all records published by the data source.")
        #self.doc[0:0] = [comment]

        # Construct inventory
        self.status = subelement(self.doc, ns, "status", "Failed")
        subelement(self.doc, ns, "created", datetime.now().isoformat())
        subelement(self.doc, ns, "service_url", self.dsaObj.getBioCASeAccessPoint())
        self.datasets = subelement(self.doc, ns, "datasets")

        # Diagnostics
        self._diagnostics = subelement(self.doc, ns, "diagnostics")

    # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    def setOKStatus(self):
        self.status.text = "OK"

    # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    def postprocessMessage(self, requestObj, dbmodVersion):
        ns = self.__class__.__protocolNS__
        if len(self.diagnosticsHandler.diagnostics) > 0:
            for d in self.diagnosticsHandler.diagnostics:
                # This check is done to skip info/debug messages that have been inserted before the DSA's debug level was loaded from config file
                if not (d.severity == 'DEBUG' and self.getPsfObj().getLogLevel() > 10) and not (d.severity == 'INFO' and self.getPsfObj().getLogLevel() > 20):
                    try:
                        subelement(self._diagnostics, ns, "diagnostic", content=d.msg.decode(self.psfObj.encoding, 'replace'), severity=d.severity, code=d.code)
                    except:
                        subelement(self._diagnostics, ns, "diagnostic", content=d.msg, severity=d.severity, code=d.code)

    # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    def setInventoryContent(self, datasetList):
        ns = self.__class__.__protocolNS__

        # Check datasetList
        if datasetList == [] or datasetList == [None]:
            log.info("No datasets published by this data source.")
            self.setOKStatus()
        else:
            log.info("Listing archives for datasets %s." % (str(datasetList)))
            try:
                # Get archive list and loop through dataset list
                i = inventory_by_dataset(self.dsaObj.name)
                for datasetTitle in datasetList:
                    ds = subelement(self.datasets, ns, "dataset")
                    subelement(ds, ns, "title", datasetTitle)
                    subelement(ds, ns, "id", datasetTitle)
                    archives = subelement(ds, ns, "archives")
                    if i.has_key(datasetTitle):
                        for _schema, NS, _fname, url, rcount, filesize, mod in i[datasetTitle]:
                            if NS is None:
                                subelement(archives, ns, "archive", url, modified=mod.isoformat(), rcount=rcount, filesize=filesize, rowType=ROWTYPE_DWCA)
                            else:
                                subelement(archives, ns, "archive", url, modified=mod.isoformat(), rcount=rcount, filesize=filesize, namespace=NS)
                # Last, set status
                self.setOKStatus()

            except Exception, err:
                log.error(err)
